@@ -29,13 +29,10 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <pthread.h>
+#include <unistd.h>
 #include "config.h"
 #include "threads.h"
 
-/* Version and greeting */
-extern const char *version, *compilation_date, *compilation_time;
-
-
 #ifndef bool
 typedef int bool;
 #endif
@@ -55,9 +52,6 @@ typedef struct {
   ref_t *start;
   ref_t *end;
   size_t size;		/* in size reference_t */
-#ifdef UNALIGNED_MALLOC
-  size_t displacement;
-#endif
 } space_t;
 
 
