@@ -15,7 +15,8 @@
 // Boston, MA 02111-1307, USA
 
 
-#ifndef INSTR_H_INCLUDED
+#ifndef _INSTR_H_INCLUDED
+#define _INSTR_H_INCLUDED
 #ifndef FAST
 extern void print_instr(int /* op_field */, int /* arg_field */, u_int16_t * /* e_pc */);
 extern void print_pc(u_int16_t * /* e_pc */);
